Learn R Programming

foodwebr (version 1.0.0)

new_foodweb: Create a new foodweb object

Description

A foodweb object describes the relationship of functions in an environment. It has two components: a funmat (function matrix) which encodes the caller/callee relationships (i.e. which functions call which) and a grviz_spec which is a text representation of the graph and is used for the default plotting behaviour.

Usage

new_foodweb(funmat)

Value

A foodweb.

Arguments

funmat

A function matrix created by foodweb_matrix()

Details

This function should not be called directly, use foodweb() instead.

See Also

foodweb