foodweb_matrix: Create a function caller/callee matrix
Description
Returns a matrix of 0s and 1s with a row and column for each function in an environment, such
that if the function on the x-axis calls the function on the y-axis, the element is 1, otherwise
0.
Usage
foodweb_matrix(env = parent.frame())
Value
An n x n matrix where n is the number of functions in env.