A foodweb object describes the relationship of functions in an environment. It has two
components: a funmat (function matrix) which encodes the caller/callee relationships (i.e.
which functions call which) and a grviz_spec which is a text representation of the graph and
is used for the default plotting behaviour.